@@ -14,15 +14,15 @@ class IsosurfaceCollection(FDSDataCollection):
 
     @property
     def quantities(self) -> List[Quantity]:
-        return list({iso.quantity for iso in self})
+        return list({iso.name for iso in self})
 
     def filter_by_quantity(self, quantity: Union[str, Quantity]):
         """Filters all isosurfaces by a specific quantity.
         """
         if type(quantity) != str:
-            quantity = quantity.quantity
+            quantity = quantity.name
         return IsosurfaceCollection(x for x in self if
-                                    x.quantity.quantity.lower() == quantity.lower() or x.quantity.label.lower() == quantity.lower())
+                                    x.name.name.lower() == quantity.lower() or x.name.label.lower() == quantity.lower())
 
     def __repr__(self):
         return "IsosurfaceCollection(" + super(IsosurfaceCollection, self).__repr__() + ")"
